@@ -1,5 +1,5 @@
 """
-TkinterWeb v3.13
+TkinterWeb v3.14
 This is a wrapper for the Tkhtml3 widget from http://tkhtml.tcl.tk/tkhtml.html, 
 which displays styled HTML documents in Tkinter.
 
@@ -73,7 +73,7 @@ class Demo():
         frame = HtmlFrame(root)
 
         frame.on_title_change(self.change_title)
-        frame.load_website("about:tkinterweb")
+        frame.load_website("https://wiki.python.org/moin/TkInter")
 
         frame.pack(expand=True, fill="both")
         root.mainloop()
