@@ -78,7 +78,7 @@ class HtmlFrame(ttk.Frame):
                                     <head><title>Error 404</title></head>
                                     <body style="text-align:center;">
                                         <h2>Oops.</h2><p></p>
-                                        <h3>The page you've requested could not be found.<h3>
+                                        <h3>The page you've requested could not be found.</h3>
                                     </body>
                                   </html>"""
         html.cursor_change_func = self.change_cursor
@@ -222,6 +222,14 @@ class HtmlFrame(ttk.Frame):
         "Get the fontsize multiplier"
         return self.html.fontscale(None)
 
+    def set_parsemode(self, mode):
+        "Set the page render mode"
+        self.html.parsemode(mode)
+
+    def get_parsemode(self):
+        "Get the page render mode"
+        return self.html.parsemode(None)
+
     def on_link_click(self, function):
         "Allows for handling link clicks"
         self.html.link_click_func = function
